Component class abstract

The application component is the building block for creating user interface controls.

Constructors

Component({Object? effectKey, Object? key})
const

Properties

effectKey → Object?
This field is intended to specify a value, which will indicate that the component requires rerendering if the previous value of this key differs from the current one.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Object?
The key is used to identify components of the same type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() → Object
The "render" method is the only method that does all the work.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited