ErrorReport class

Constructors

ErrorReport(Object? error, StackTrace? stackTrace)

Properties

error → Object?
final
errorReport → ValueNotifier<ErrorReport?>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

global ↔ ValueNotifier<ErrorReport?>
getter/setter pair

Static Methods

run<T>(T f()) → T
runAsync<T>(Future<T> f()) → Future<T>