InheritedValue class

The InheritedValue feature provides functionality to make it possible for child components to access a "value" declared in a parent component.

By "value" is meant a value (object) whose changes need to be tracked.

Constructors

InheritedValue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

add<T>(String key, T init()) → ValueNotifier<T>
Adds an inherited "value" and listens for its changes. Used in the parent component.
get<T>(String key) → ValueNotifier<T>?
Allows to get an inherited "value" and add listener for its changes. Used in child components.