Init class

The Init function provides the functionality to implement "init" and "dispose" methods for the component.

The implementation of the "dispose" method is optional.

Constructors

Init()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

use(void Function()? handler()) → void
The use method takes the "init" function as an argument. The "init" function can return a function that will be used as "dispose".
useWithKey(String key, void Function()? handler()) → void
The use method takes a key key and the "init" function as an argument. The "init" function can return a function that will be used as "dispose".