VComponent class

Inheritance

Constructors

VComponent(Component component)

Properties

child ↔ VNode?
getter/setter pair
component ↔ Component
getter/setter pair
context ↔ Map<String, Map<String, Object?>>
getter/setter pair
dirty ↔ bool
getter/setter pair
disposed ↔ bool
getter/setter pairinherited
error ↔ Object?
getter/setter pairinherited
errorReport ↔ ValueNotifier<ErrorReport?>?
getter/setter pair
hasError ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
key ↔ Object?
getter/setter pairinherited
kind → VNodeKind
no setteroverride
node ↔ Node?
getter/setter pairoverride
onDispose ↔ List<void Function()>?
getter/setter pair
parent ↔ VNode?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ StackTrace?
getter/setter pairinherited

Methods

addDisposeHandler(VComponent vComponent, void handler()) → void
dispose() → void
override
findErrorReport() → ValueNotifier<ErrorReport?>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(VNode newVNode, bool canDispose) → void
override
render(VNode newVNode, bool canDispose) → VNode
Renders an existing (this) virtual node or a newly created newVNode node.
override
renderAndReplace(VNode? parent, Node node) → void
Renders a newly created (this) virtual node and replaces the content of node with the new content.
inherited
renderNew(VNode? parent) → void
Renders the newly created virtual node.
override
renderSafely<T>(T render()) → T
inherited
toString() → String
A string representation of this object.
override
updateElement(Map<String, Object> oldAttributes, Map<String, Object> newAttributes, Map<String, void Function(Event event)> oldListeners, Map<String, void Function(Event event)> newListeners) → void
inherited
wrapListener(void listener(Event event)?) → void Function(Event event)?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current ↔ VComponent?
getter/setter pair

Static Methods

run<T>(T action(VComponent vComponent)) → T
runWith<T>(VComponent vComponent, T action(VComponent vComponent)) → T