VNode class abstract

Virtual node.

Implementers

Constructors

VNode()

Properties

disposed ↔ bool
getter/setter pair
error ↔ Object?
getter/setter pair
hasError ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ Object?
getter/setter pair
kind → VNodeKind
no setter
node ↔ Node?
getter/setter pair
parent ↔ VNode?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ StackTrace?
getter/setter pair

Methods

dispose() → void
findErrorReport() → ValueNotifier<ErrorReport?>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(VNode newVNode, bool canDispose) → void
render(VNode newVNode, bool canDispose) → VNode
Renders an existing (this) virtual node or a newly created newVNode node.
renderAndReplace(VNode? parent, Node node) → void
Renders a newly created (this) virtual node and replaces the content of node with the new content.
renderNew(VNode? parent) → void
Renders the newly created virtual node.
renderSafely<T>(T render()) → T
toString() → String
A string representation of this object.
inherited
updateElement(Map<String, Object> oldAttributes, Map<String, Object> newAttributes, Map<String, void Function(Event event)> oldListeners, Map<String, void Function(Event event)> newListeners) → void
wrapListener(void listener(Event event)?) → void Function(Event event)?

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isEqual(VNode vNode1, VNode vNode2) → bool