VNodeEntry class

Represents a linked list entry of virtual nodes.

Inheritance

Constructors

VNodeEntry(VNode vNode)

Properties

hashCode → int
The hash code for this object.
no setterinherited
list → LinkedList<VNodeEntry>?
The linked list containing this element.
no setterinherited
next → VNodeEntry?
The successor of this element in its linked list.
no setterinherited
previous → VNodeEntry?
The predecessor of this element in its linked list.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vNode ↔ VNode
getter/setter pair

Methods

insertAfter(VNodeEntry entry) → void
Insert an element after this element in this element's linked list.
inherited
insertBefore(VNodeEntry entry) → void
Insert an element before this element in this element's linked list.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
Unlink the element from its linked list.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited