VTree class

Constructors

VTree(VElement parent, Node parentNode)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → VElement
final
parentNode → Node
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(LinkedList<VNodeEntry> oldList, LinkedList<VNodeEntry> newList) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited